Application
===========

.. autoclass:: qbittorrentapi.app.AppAPIMixIn
    :members:
    :undoc-members:
    :exclude-members: app, application, app_webapiVersion, app_buildInfo, app_setPreferences, app_defaultSavePath, app_setCookies, app_networkInterfaceAddressList, app_networkInterfaceList, app_sendTestEmail, app_getDirectoryContent
    :show-inheritance:

.. autoclass:: qbittorrentapi.app.Application
    :members:
    :undoc-members:
    :exclude-members: app, application, webapiVersion, buildInfo, setPreferences, defaultSavePath, setCookies, networkInterfaceAddressList, networkInterfaceList, sendTestEmail, getDirectoryContent

.. autoclass:: qbittorrentapi.app.ApplicationPreferencesDictionary
    :members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: qbittorrentapi.app.BuildInfoDictionary
    :members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: qbittorrentapi.app.DirectoryContentList
    :members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: qbittorrentapi.app.Cookie
    :members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: qbittorrentapi.app.CookieList
    :members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: qbittorrentapi.app.NetworkInterfaceList
    :members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: qbittorrentapi.app.NetworkInterface
    :members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: qbittorrentapi.app.NetworkInterfaceAddressList
    :members:
    :undoc-members:
    :show-inheritance:
